@@ -4,6 +4,8 @@ var searchData=
   ['aubio_5fbintomidi',['aubio_bintomidi',['../musicutils_8h.html#aa73e67530bdc66bfa08ee4f08e48c3fc',1,'musicutils.h']]],
   ['aubio_5fcleanup',['aubio_cleanup',['../musicutils_8h.html#a2b5d813f8d70b69add6f4811a68c9424',1,'musicutils.h']]],
   ['aubio_5fdb_5fspl',['aubio_db_spl',['../musicutils_8h.html#a3493315027a046c796045c3ef1bd2d75',1,'musicutils.h']]],
+  ['aubio_5fdct_5fdo',['aubio_dct_do',['../dct_8h.html#aa34059719b811308528fddf68e25ac81',1,'dct.h']]],
+  ['aubio_5fdct_5frdo',['aubio_dct_rdo',['../dct_8h.html#a92512b1226110ba73e209bce822e1718',1,'dct.h']]],
   ['aubio_5ffft_5fdo',['aubio_fft_do',['../fft_8h.html#af2a5dcf62bbb1feb5774591c9f449155',1,'fft.h']]],
   ['aubio_5ffft_5fdo_5fcomplex',['aubio_fft_do_complex',['../fft_8h.html#ad25d21808e97f526a975d9ea0731c4ec',1,'fft.h']]],
   ['aubio_5ffft_5fget_5fimag',['aubio_fft_get_imag',['../fft_8h.html#ac2754200d4e3d9b2779c702ed796785a',1,'fft.h']]],
@@ -28,23 +30,42 @@ var searchData=
   ['aubio_5ffilter_5fset_5fsamplerate',['aubio_filter_set_samplerate',['../filter_8h.html#a41f31bc7c6f443c978bb37b94f7e3fe5',1,'filter.h']]],
   ['aubio_5ffilterbank_5fdo',['aubio_filterbank_do',['../filterbank_8h.html#ac0db64af08c9695145212ecfeadffaee',1,'filterbank.h']]],
   ['aubio_5ffilterbank_5fget_5fcoeffs',['aubio_filterbank_get_coeffs',['../filterbank_8h.html#aea299261b359934c437c443f57a79185',1,'filterbank.h']]],
+  ['aubio_5ffilterbank_5fget_5fnorm',['aubio_filterbank_get_norm',['../filterbank_8h.html#a44f95ed742ec620caff78dbaad607d2a',1,'filterbank.h']]],
+  ['aubio_5ffilterbank_5fget_5fpower',['aubio_filterbank_get_power',['../filterbank_8h.html#aef64d639d8208eaf35fd6d6a6192bcaf',1,'filterbank.h']]],
   ['aubio_5ffilterbank_5fset_5fcoeffs',['aubio_filterbank_set_coeffs',['../filterbank_8h.html#a9f8999d9cdbc3cb34814a57e727c4588',1,'filterbank.h']]],
+  ['aubio_5ffilterbank_5fset_5fmel_5fcoeffs',['aubio_filterbank_set_mel_coeffs',['../filterbank__mel_8h.html#a3d1714f1bf761d32d759acf8f47121b7',1,'filterbank_mel.h']]],
+  ['aubio_5ffilterbank_5fset_5fmel_5fcoeffs_5fhtk',['aubio_filterbank_set_mel_coeffs_htk',['../filterbank__mel_8h.html#aa525658a77256e6c060185d418028e12',1,'filterbank_mel.h']]],
   ['aubio_5ffilterbank_5fset_5fmel_5fcoeffs_5fslaney',['aubio_filterbank_set_mel_coeffs_slaney',['../filterbank__mel_8h.html#a3b8bc12b63734459675d28cb49ec4bbb',1,'filterbank_mel.h']]],
+  ['aubio_5ffilterbank_5fset_5fnorm',['aubio_filterbank_set_norm',['../filterbank_8h.html#a6d18e037d48201284d8d4f849ecb4589',1,'filterbank.h']]],
+  ['aubio_5ffilterbank_5fset_5fpower',['aubio_filterbank_set_power',['../filterbank_8h.html#a0457c20c6d57ffbdbf6b28ddd6e45c2c',1,'filterbank.h']]],
   ['aubio_5ffilterbank_5fset_5ftriangle_5fbands',['aubio_filterbank_set_triangle_bands',['../filterbank__mel_8h.html#a9f8645e5cb1ac0dcb2146d20eeb3aa60',1,'filterbank_mel.h']]],
   ['aubio_5ffreqtobin',['aubio_freqtobin',['../musicutils_8h.html#af3a7e117c7c2e06ce8defa90f1d8e170',1,'musicutils.h']]],
   ['aubio_5ffreqtomidi',['aubio_freqtomidi',['../musicutils_8h.html#a26df6f267c73981029ced924c0572f82',1,'musicutils.h']]],
+  ['aubio_5fhztomel',['aubio_hztomel',['../musicutils_8h.html#af3af609c484fbe779b713238a8f332c3',1,'musicutils.h']]],
+  ['aubio_5fhztomel_5fhtk',['aubio_hztomel_htk',['../musicutils_8h.html#a85cf5c3a7e227ddb6222c1adf2c93047',1,'musicutils.h']]],
   ['aubio_5flevel_5fdetection',['aubio_level_detection',['../musicutils_8h.html#a1093c5cd5f170472079f398b617afd2d',1,'musicutils.h']]],
   ['aubio_5flevel_5flin',['aubio_level_lin',['../musicutils_8h.html#a173a3ff4d0282069edf599e31559565e',1,'musicutils.h']]],
   ['aubio_5flog_5freset',['aubio_log_reset',['../log_8h.html#a75d76b14ebbbc909cea2960a075bcf94',1,'log.h']]],
   ['aubio_5flog_5fset_5ffunction',['aubio_log_set_function',['../log_8h.html#a15b6581e2a2d7229cf781a3e03c5b2f1',1,'log.h']]],
   ['aubio_5flog_5fset_5flevel_5ffunction',['aubio_log_set_level_function',['../log_8h.html#a7ee71b864965893bdcc1cc06a69d9618',1,'log.h']]],
+  ['aubio_5fmeltohz',['aubio_meltohz',['../musicutils_8h.html#a6279bc3631d75e063765e16218dfab48',1,'musicutils.h']]],
+  ['aubio_5fmeltohz_5fhtk',['aubio_meltohz_htk',['../musicutils_8h.html#a21704d1d601ade97861faad803cd1744',1,'musicutils.h']]],
   ['aubio_5fmfcc_5fdo',['aubio_mfcc_do',['../mfcc_8h.html#a5ba02ef93b32a5db05fe50f0b81bd64b',1,'mfcc.h']]],
+  ['aubio_5fmfcc_5fget_5fpower',['aubio_mfcc_get_power',['../mfcc_8h.html#a0d3cf5138292c33eb33f031b8b418b58',1,'mfcc.h']]],
+  ['aubio_5fmfcc_5fget_5fscale',['aubio_mfcc_get_scale',['../mfcc_8h.html#a8cf21d8824a688f0776ee8c4be09c839',1,'mfcc.h']]],
+  ['aubio_5fmfcc_5fset_5fmel_5fcoeffs',['aubio_mfcc_set_mel_coeffs',['../mfcc_8h.html#a5ac44264c98aeab62e459b784cadc291',1,'mfcc.h']]],
+  ['aubio_5fmfcc_5fset_5fmel_5fcoeffs_5fhtk',['aubio_mfcc_set_mel_coeffs_htk',['../mfcc_8h.html#a7faf085d0e973760ce5d459f192715f0',1,'mfcc.h']]],
+  ['aubio_5fmfcc_5fset_5fmel_5fcoeffs_5fslaney',['aubio_mfcc_set_mel_coeffs_slaney',['../mfcc_8h.html#a7f8047980cdfa12ba715aa0df966a731',1,'mfcc.h']]],
+  ['aubio_5fmfcc_5fset_5fpower',['aubio_mfcc_set_power',['../mfcc_8h.html#a0d745097651d063f229536a4681998ef',1,'mfcc.h']]],
+  ['aubio_5fmfcc_5fset_5fscale',['aubio_mfcc_set_scale',['../mfcc_8h.html#a5e540261b135d8f2cc1eb6307ff2e195',1,'mfcc.h']]],
   ['aubio_5fmiditobin',['aubio_miditobin',['../musicutils_8h.html#a4ca9575b66357f1e75e4ead52f73f720',1,'musicutils.h']]],
   ['aubio_5fmiditofreq',['aubio_miditofreq',['../musicutils_8h.html#ae1417d0e88f401df87538182bfb9272f',1,'musicutils.h']]],
   ['aubio_5fnotes_5fdo',['aubio_notes_do',['../notes_8h.html#a39f3639a37f50cf0b8c03918be7beee0',1,'notes.h']]],
   ['aubio_5fnotes_5fget_5fminioi_5fms',['aubio_notes_get_minioi_ms',['../notes_8h.html#aaa6737fb1e7bd6ef5051c2818de99fb5',1,'notes.h']]],
+  ['aubio_5fnotes_5fget_5frelease_5fdrop',['aubio_notes_get_release_drop',['../notes_8h.html#a09d85c7484d2a5c2c81f9e496d9c9582',1,'notes.h']]],
   ['aubio_5fnotes_5fget_5fsilence',['aubio_notes_get_silence',['../notes_8h.html#a1aebbbca58a3a5ced4dd1bb3dda30689',1,'notes.h']]],
   ['aubio_5fnotes_5fset_5fminioi_5fms',['aubio_notes_set_minioi_ms',['../notes_8h.html#a01a1960076ec18b38e98a91a922a8820',1,'notes.h']]],
+  ['aubio_5fnotes_5fset_5frelease_5fdrop',['aubio_notes_set_release_drop',['../notes_8h.html#a85a6bea1b294b5b6037a5b2b2e16ff04',1,'notes.h']]],
   ['aubio_5fnotes_5fset_5fsilence',['aubio_notes_set_silence',['../notes_8h.html#ae95d432d965385e5795551264a22de0f',1,'notes.h']]],
   ['aubio_5fonset_5fdo',['aubio_onset_do',['../onset_8h.html#a3329b2f251f75556a08bc56ae57cb5fa',1,'onset.h']]],
   ['aubio_5fonset_5fget_5fawhitening',['aubio_onset_get_awhitening',['../onset_8h.html#a6afeb2c904a717fa675c347d2f15aa52',1,'onset.h']]],
